@@ -24,8 +24,11 @@ def publish(topic, body=None, path=None, json_encoder=None) -> None:
 
     message = json.dumps(message, cls=json_encoder)
     message = json.dumps({"default": message})
+
+    topic_arn = f'{settings.AWS_SNS_PATH}{settings.ENVIRONMENT}-{topic}'
+    print('SNS publishing:', topic_arn, message)
     resp = client.publish(
-        TopicArn=f'{settings.AWS_SNS_PATH}{settings.ENVIRONMENT}-{topic}',
+        TopicArn=topic_arn,
         Message=message,
         MessageStructure="json",
     )
