@@ -27,7 +27,7 @@ class ServiceUrl:
     matching = srv_record('matching-service', 'srv')
     tms = srv_record('tms-service', 'srv')
     location = srv_record('location-service', 'srv')
-    pricing = srv_record('pricing-service', 'srv'),
+    pricing = srv_record('pricing-service', 'srv')
 
 
 service_url = ServiceUrl(os.environ.get('ENVIRONMENT', 'dev'))
